StringExtension extension
Extension method for String to capitalize the first letter.
- on
Methods
-
capitalize(
) → String -
Available on String, provided by the StringExtension extension
Extension method for String to capitalize the first letter.
Available on String, provided by the StringExtension extension